@@ -1,5 +1,5 @@
 /* libinfinity - a GObject-based infinote implementation
- * Copyright (C) 2007, 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2007-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -595,7 +595,7 @@ inf_adopted_undo_grouping_class_init(gpointer g_class,
     "group-requests",
     G_OBJECT_CLASS_TYPE(object_class),
     G_SIGNAL_RUN_LAST,
-    G_STRUCT_OFFSET(InfAdoptedAlgorithmClass, can_undo_changed),
+    G_STRUCT_OFFSET(InfAdoptedUndoGroupingClass, group_requests),
     g_signal_accumulator_true_handled, NULL,
     inf_marshal_BOOLEAN__OBJECT_OBJECT,
     G_TYPE_BOOLEAN,
@@ -785,7 +785,7 @@ inf_adopted_undo_grouping_start_group(InfAdoptedUndoGrouping* grouping,
 }
 
 /**
- * inf_adopted_undo_grouping_end_group.
+ * inf_adopted_undo_grouping_end_group:
  * @grouping: A #InfAdoptedUndoGrouping.
  * @allow_group_with_next: Whether subsequent requests are allow to be part of
  * this group if #InfAdoptedUndoGrouping::group-requests allows.
