@@ -1,5 +1,5 @@
 /* libinfinity - a GObject-based infinote implementation
- * Copyright (C) 2007, 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2007-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,6 +32,7 @@
 
 #include <gsasl.h>
 
+#include <unistd.h> /* Get ssize_t on MSVC, required by gnutls.h */
 #include <gnutls/gnutls.h>
 
 /* TODO: Cache GQuarks */
@@ -196,6 +197,8 @@ inf_directory_strerror(InfDirectoryError code)
     return _("Received sync-in message without having requested a sync-in");
   case INF_DIRECTORY_ERROR_UNEXPECTED_MESSAGE:
     return _("Unexpected XML message");
+  case INF_DIRECTORY_ERROR_NO_STORAGE:
+    return _("Server does not have a background storage");
   case INF_DIRECTORY_ERROR_FAILED:
     return _("An unknown directory error has occured");
   default:
@@ -203,6 +206,49 @@ inf_directory_strerror(InfDirectoryError code)
   }
 }
 
+/**
+ * inf_authentication_detail_error_quark:
+ *
+ * Error domain for further information on authentication errors. Errors in
+ * this domain will be from the #InfAuthenticationDetailError enumeration.
+ * See #GError for information on error domains.
+ *
+ * Returns: A GQuark.
+ */
+GQuark
+inf_authentication_detail_error_quark(void)
+{
+  return g_quark_from_static_string("INF_AUTHENTICATION_DETAIL_ERROR");
+}
+
+
+/**
+ * inf_authentication_detail_strerror:
+ * @code: An error code from the #InfAuthenticationDetailError enumeration.
+ *
+ * Returns a human-readable string for the given error code.
+ *
+ * Returns: A static string that must not be freed.
+ */
+const gchar*
+inf_authentication_detail_strerror(InfAuthenticationDetailError code)
+{
+  switch(code)
+  {
+  case INF_AUTHENTICATION_DETAIL_ERROR_AUTHENTICATION_FAILED:
+    return _("User did not provide valid credentials.");
+  case INF_AUTHENTICATION_DETAIL_ERROR_USER_NOT_AUTHORIZED:
+    return _("User is not permitted to connect to this server.");
+  case INF_AUTHENTICATION_DETAIL_ERROR_TRY_AGAIN:
+    return _("Authentication was temporarily "
+             "interrupted on the server side.");
+  case INF_AUTHENTICATION_DETAIL_ERROR_SERVER_ERROR:
+    return _("An error cocured while checking user permissions.");
+  default:
+    return _("An error with unknown code has occured");
+  }
+}
+
 /**
  * inf_gnutls_error_quark:
  *
