@@ -1,5 +1,5 @@
 /* libinfinity - a GObject-based infinote implementation
- * Copyright (C) 2007, 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2007-2010 Armin Burgmeier <armin@arbur.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -136,6 +136,8 @@ typedef enum _InfUserError {
  * sync to the server.
  * @INF_DIRECTORY_ERROR_UNEXPECTED_MESSAGE: A message that is not understood
  * was received.
+ * @INF_DIRECTORY_ERROR_NO_STORAGE: A node cannot be stored permanently on the
+ * server since it has no storage backend attached.
  * @INF_DIRECTORY_ERROR_FAILED: Generic error code when no further reason of
  * failure is known.
  *
@@ -163,10 +165,29 @@ typedef enum _InfDirectoryError {
   INF_DIRECTORY_ERROR_METHOD_UNSUPPORTED,
   INF_DIRECTORY_ERROR_UNEXPECTED_SYNC_IN,
   INF_DIRECTORY_ERROR_UNEXPECTED_MESSAGE,
+  INF_DIRECTORY_ERROR_NO_STORAGE,
 
   INF_DIRECTORY_ERROR_FAILED
 } InfDirectoryError;
 
+/**
+ * InfAuthenticationDetailError:
+ * @INF_AUTHENTICATION_DETAIL_ERROR_AUTHENTICATION_FAILED: User did not provide
+ * valid credentials.
+ * @INF_AUTHENTICATION_DETAIL_ERROR_USER_NOT_AUTHORIZED: User is not permitted
+ * to connect to this server.
+ * @INF_AUTHENTICATION_DETAIL_ERROR_TRY_AGAIN: Authentication was temporarily
+ * interrupted on the server side.
+ * @INF_AUTHENTICATION_DETAIL_ERROR_SERVER_ERROR: An error occured while
+ * checking user permissions.
+ */
+typedef enum _InfAuthenticationDetailError {
+  INF_AUTHENTICATION_DETAIL_ERROR_AUTHENTICATION_FAILED,
+  INF_AUTHENTICATION_DETAIL_ERROR_USER_NOT_AUTHORIZED,
+  INF_AUTHENTICATION_DETAIL_ERROR_TRY_AGAIN,
+  INF_AUTHENTICATION_DETAIL_ERROR_SERVER_ERROR
+} InfAuthenticationDetailError;
+
 GQuark
 inf_request_error_quark(void);
 
@@ -185,6 +206,12 @@ inf_directory_error_quark(void);
 const gchar*
 inf_directory_strerror(InfDirectoryError code);
 
+const gchar*
+inf_authentication_detail_strerror(InfAuthenticationDetailError code);
+
+GQuark
+inf_authentication_detail_error_quark(void);
+
 GQuark
 inf_gnutls_error_quark(void);
 
