@@ -23,18 +23,10 @@ extern void inf_marshal_VOID__BOXED_DOUBLE_DOUBLE (GClosure     *closure,
 /* VOID:OBJECT (inf-marshal.in:4) */
 #define inf_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
-/* VOID:UINT,UINT,OBJECT (inf-marshal.in:5) */
-extern void inf_marshal_VOID__UINT_UINT_OBJECT (GClosure     *closure,
-                                                GValue       *return_value,
-                                                guint         n_param_values,
-                                                const GValue *param_values,
-                                                gpointer      invocation_hint,
-                                                gpointer      marshal_data);
-
-/* VOID:POINTER (inf-marshal.in:6) */
+/* VOID:POINTER (inf-marshal.in:5) */
 #define inf_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:OBJECT,DOUBLE (inf-marshal.in:7) */
+/* VOID:OBJECT,DOUBLE (inf-marshal.in:6) */
 extern void inf_marshal_VOID__OBJECT_DOUBLE (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -42,7 +34,7 @@ extern void inf_marshal_VOID__OBJECT_DOUBLE (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,POINTER (inf-marshal.in:8) */
+/* VOID:OBJECT,POINTER (inf-marshal.in:7) */
 extern void inf_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -50,7 +42,7 @@ extern void inf_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:POINTER,UINT (inf-marshal.in:9) */
+/* VOID:POINTER,UINT (inf-marshal.in:8) */
 extern void inf_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -58,10 +50,10 @@ extern void inf_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:UINT (inf-marshal.in:10) */
+/* VOID:UINT (inf-marshal.in:9) */
 #define inf_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
 
-/* VOID:UINT,UINT (inf-marshal.in:11) */
+/* VOID:UINT,UINT (inf-marshal.in:10) */
 extern void inf_marshal_VOID__UINT_UINT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -69,7 +61,7 @@ extern void inf_marshal_VOID__UINT_UINT (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* VOID:OBJECT,BOOLEAN (inf-marshal.in:12) */
+/* VOID:OBJECT,BOOLEAN (inf-marshal.in:11) */
 extern void inf_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -77,7 +69,7 @@ extern void inf_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:UINT,BOXED,OBJECT (inf-marshal.in:13) */
+/* VOID:UINT,BOXED,OBJECT (inf-marshal.in:12) */
 extern void inf_marshal_VOID__UINT_BOXED_OBJECT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -85,15 +77,15 @@ extern void inf_marshal_VOID__UINT_BOXED_OBJECT (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:UINT,INT (inf-marshal.in:14) */
-extern void inf_marshal_VOID__UINT_INT (GClosure     *closure,
-                                        GValue       *return_value,
-                                        guint         n_param_values,
-                                        const GValue *param_values,
-                                        gpointer      invocation_hint,
-                                        gpointer      marshal_data);
+/* VOID:UINT,INT,BOOLEAN (inf-marshal.in:13) */
+extern void inf_marshal_VOID__UINT_INT_BOOLEAN (GClosure     *closure,
+                                                GValue       *return_value,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint,
+                                                gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT (inf-marshal.in:15) */
+/* VOID:OBJECT,OBJECT (inf-marshal.in:14) */
 extern void inf_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -101,7 +93,7 @@ extern void inf_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:BOXED,OBJECT (inf-marshal.in:16) */
+/* VOID:BOXED,OBJECT (inf-marshal.in:15) */
 extern void inf_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -109,7 +101,7 @@ extern void inf_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:BOXED,BOXED,OBJECT (inf-marshal.in:17) */
+/* VOID:BOXED,BOXED,OBJECT (inf-marshal.in:16) */
 extern void inf_marshal_VOID__BOXED_BOXED_OBJECT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -117,7 +109,7 @@ extern void inf_marshal_VOID__BOXED_BOXED_OBJECT (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT,BOOLEAN (inf-marshal.in:18) */
+/* VOID:OBJECT,OBJECT,BOOLEAN (inf-marshal.in:17) */
 extern void inf_marshal_VOID__OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -125,13 +117,13 @@ extern void inf_marshal_VOID__OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
 
-/* VOID:DOUBLE (inf-marshal.in:19) */
+/* VOID:DOUBLE (inf-marshal.in:18) */
 #define inf_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE
 
-/* VOID:ENUM (inf-marshal.in:20) */
+/* VOID:ENUM (inf-marshal.in:19) */
 #define inf_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-/* BOOLEAN:OBJECT,OBJECT (inf-marshal.in:21) */
+/* BOOLEAN:OBJECT,OBJECT (inf-marshal.in:20) */
 extern void inf_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -139,7 +131,7 @@ extern void inf_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:OBJECT,UINT (inf-marshal.in:22) */
+/* VOID:OBJECT,UINT (inf-marshal.in:21) */
 extern void inf_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -147,6 +139,22 @@ extern void inf_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
+/* POINTER:POINTER (inf-marshal.in:22) */
+extern void inf_marshal_POINTER__POINTER (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data);
+
+/* POINTER:OBJECT,POINTER (inf-marshal.in:23) */
+extern void inf_marshal_POINTER__OBJECT_POINTER (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* __inf_marshal_MARSHAL_H__ */
