@@ -1,5 +1,5 @@
 /* libinfinity - a GObject-based infinote implementation
- * Copyright (C) 2007, 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2007-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,7 +37,6 @@ struct _InfTextGtkHueChooserPrivate {
   gdouble hue;
 
   GdkWindow* window;
-  GdkGC* gc;
 
   guint ring_width;
   guint size;
@@ -153,6 +152,7 @@ inf_text_gtk_hue_chooser_is_in_ring(InfTextGtkHueChooser* chooser,
                                     gdouble y)
 {
   InfTextGtkHueChooserPrivate* priv;
+  GtkAllocation allocation;
   gdouble center_x;
   gdouble center_y;
   gdouble dx;
@@ -161,9 +161,15 @@ inf_text_gtk_hue_chooser_is_in_ring(InfTextGtkHueChooser* chooser,
   gdouble outer;
   gdouble dist_sqr;
 
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_get_allocation(GTK_WIDGET(chooser), &allocation);
+#else
+  allocation = GTK_WIDGET(chooser)->allocation;
+#endif
+
   priv = INF_TEXT_GTK_HUE_CHOOSER_PRIVATE(chooser);
-  center_x = GTK_WIDGET(chooser)->allocation.width / 2.0;
-  center_y = GTK_WIDGET(chooser)->allocation.height / 2.0;
+  center_x = allocation.width / 2.0;
+  center_y = allocation.height / 2.0;
   outer = priv->size / 2.0;
   inner = outer - priv->ring_width;
   dx = x - center_x;
@@ -178,14 +184,21 @@ inf_text_gtk_hue_chooser_hue_by_coords(InfTextGtkHueChooser* chooser,
                                        gdouble x,
                                        gdouble y)
 {
+  GtkAllocation allocation;
   double center_x;
   double center_y;
   double dx;
   double dy;
   double angle;
 
-  center_x = GTK_WIDGET(chooser)->allocation.width / 2.0;
-  center_y = GTK_WIDGET(chooser)->allocation.height / 2.0;
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_get_allocation(GTK_WIDGET(chooser), &allocation);
+#else
+  allocation = GTK_WIDGET(chooser)->allocation;
+#endif
+
+  center_x = allocation.width / 2.0;
+  center_y = allocation.height / 2.0;
 
   dx = x - center_x;
   dy = center_y - y;
@@ -205,6 +218,7 @@ inf_text_gtk_hue_chooser_paint(InfTextGtkHueChooser* chooser,
                                gint height)
 {
   InfTextGtkHueChooserPrivate* priv;
+  GtkAllocation allocation;
   int xx, yy;
   gdouble dx, dy, dist;
   gdouble center_x;
@@ -232,8 +246,14 @@ inf_text_gtk_hue_chooser_paint(InfTextGtkHueChooser* chooser,
     NULL
   );
 
-  center_x = GTK_WIDGET(chooser)->allocation.width / 2.0;
-  center_y = GTK_WIDGET(chooser)->allocation.height / 2.0;
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_get_allocation(GTK_WIDGET(chooser), &allocation);
+#else
+  allocation = GTK_WIDGET(chooser)->allocation;
+#endif
+
+  center_x = allocation.width / 2.0;
+  center_y = allocation.height / 2.0;
 
   outer = priv->size / 2.0;
   inner = outer - priv->ring_width;
@@ -352,12 +372,16 @@ inf_text_gtk_hue_chooser_init(GTypeInstance* instance,
   hue_chooser = INF_TEXT_GTK_HUE_CHOOSER(instance);
   priv = INF_TEXT_GTK_HUE_CHOOSER_PRIVATE(hue_chooser);
 
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_set_has_window(GTK_WIDGET(hue_chooser), FALSE);
+  gtk_widget_set_can_focus(GTK_WIDGET(hue_chooser), TRUE);
+#else
   GTK_WIDGET_SET_FLAGS(hue_chooser, GTK_NO_WINDOW);
   GTK_WIDGET_SET_FLAGS(hue_chooser, GTK_CAN_FOCUS);
+#endif
 
   priv->hue = 0.0;
   priv->window = NULL;
-  priv->gc = NULL;
   priv->ring_width = 50;
   priv->size = 240;
   priv->mode = INF_TEXT_GTK_HUE_CHOOSER_DRAG_NONE;
@@ -468,19 +492,30 @@ inf_text_gtk_hue_chooser_realize(GtkWidget* widget)
 {
   InfTextGtkHueChooser* chooser;
   InfTextGtkHueChooserPrivate* priv;
+  GtkAllocation allocation;
   GdkWindowAttr attr;
   GdkWindow* parent_window;
 
   chooser = INF_TEXT_GTK_HUE_CHOOSER(widget);
   priv = INF_TEXT_GTK_HUE_CHOOSER_PRIVATE(chooser);
 
+#if GTK_CHECK_VERSION(2,20,0)
+  gtk_widget_set_realized(widget, TRUE);
+#else
   GTK_WIDGET_SET_FLAGS(widget, GTK_REALIZED);
+#endif
+
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_get_allocation(widget, &allocation);
+#else
+  allocation = widget->allocation;
+#endif
 
   attr.window_type = GDK_WINDOW_CHILD;
-  attr.x = widget->allocation.x;
-  attr.y = widget->allocation.y;
-  attr.width = widget->allocation.width;
-  attr.height = widget->allocation.height;
+  attr.x = allocation.x;
+  attr.y = allocation.y;
+  attr.width = allocation.width;
+  attr.height = allocation.height;
   attr.wclass = GDK_INPUT_ONLY;
   attr.event_mask = gtk_widget_get_events(widget);
   attr.event_mask |= (
@@ -493,14 +528,20 @@ inf_text_gtk_hue_chooser_realize(GtkWidget* widget)
   );
 
   parent_window = gtk_widget_get_parent_window(widget);
+  g_object_ref(parent_window);
+
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_set_window(widget, parent_window);
+#else
   widget->window = parent_window;
-  g_object_ref(widget->window);
+#endif
 
   priv->window = gdk_window_new(parent_window, &attr, GDK_WA_X | GDK_WA_Y);
   gdk_window_set_user_data(priv->window, chooser);
-  widget->style = gtk_style_attach(widget->style, widget->window);
-
-  priv->gc = gdk_gc_new(parent_window);
+  gtk_widget_set_style(
+    widget,
+    gtk_style_attach(gtk_widget_get_style(widget), parent_window)
+  );
 }
 
 static void
@@ -516,15 +557,11 @@ inf_text_gtk_hue_chooser_unrealize(GtkWidget* widget)
   gdk_window_destroy(priv->window);
   priv->window = NULL;
 
-  g_object_unref(priv->gc);
-  priv->gc = NULL;
-
   GTK_WIDGET_CLASS(parent_class)->unrealize(widget);
 }
 
-static void
-inf_text_gtk_hue_chooser_size_request(GtkWidget* widget,
-                                      GtkRequisition* requisition)
+static gint
+inf_text_gtk_hue_chooser_calculate_width_and_height(GtkWidget *widget)
 {
   InfTextGtkHueChooser* chooser;
   InfTextGtkHueChooserPrivate* priv;
@@ -541,10 +578,39 @@ inf_text_gtk_hue_chooser_size_request(GtkWidget* widget,
     NULL
   );
 
-  requisition->width = priv->size + 2 * (focus_width + focus_pad);
-  requisition->height = priv->size + 2 * (focus_width + focus_pad);
+  return priv->size + 2 * (focus_width + focus_pad);
 }
 
+#if GTK_CHECK_VERSION(2,91,6)
+static void
+inf_text_gtk_hue_chooser_get_preferred_width(GtkWidget *widget,
+                                             gint *minimum,
+                                             gint *natural)
+{
+  *minimum = *natural =
+    inf_text_gtk_hue_chooser_calculate_width_and_height(widget);
+}
+
+static void
+inf_text_gtk_hue_chooser_get_preferred_height(GtkWidget *widget,
+                                              gint *minimum,
+                                              gint *natural)
+{
+  *minimum = *natural =
+    inf_text_gtk_hue_chooser_calculate_width_and_height(widget);
+}
+
+#else
+
+static void
+inf_text_gtk_hue_chooser_size_request(GtkWidget* widget,
+                                      GtkRequisition* requisition)
+{
+  requisition->width = requisition->height =
+    inf_text_gtk_hue_chooser_calculate_width_and_height(widget);
+}
+#endif
+
 static void
 inf_text_gtk_hue_chooser_size_allocate(GtkWidget* widget,
                                        GtkAllocation* allocation)
@@ -555,9 +621,17 @@ inf_text_gtk_hue_chooser_size_allocate(GtkWidget* widget,
   chooser = INF_TEXT_GTK_HUE_CHOOSER(widget);
   priv = INF_TEXT_GTK_HUE_CHOOSER_PRIVATE(chooser);
 
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_set_allocation(widget, allocation);
+#else
   widget->allocation = *allocation;
+#endif
 
+#if GTK_CHECK_VERSION(2,20,0)
+  if(gtk_widget_get_realized(widget))
+#else
   if(GTK_WIDGET_REALIZED(widget))
+#endif
   {
     /* TODO: Keep 1:1 aspect ratio, center within allocation, set size
      * accordingly, always request only ring_width * 2. */
@@ -601,6 +675,19 @@ inf_text_gtk_hue_chooser_button_press_event(GtkWidget* widget,
       GDK_CROSSHAIR
     );
 
+#if GTK_CHECK_VERSION(2, 91, 0)
+    gdk_device_grab(
+      gdk_event_get_device((GdkEvent*)event),
+      priv->window,
+      GDK_OWNERSHIP_NONE,
+      FALSE,
+      GDK_POINTER_MOTION_MASK |
+      GDK_POINTER_MOTION_HINT_MASK |
+      GDK_BUTTON_RELEASE_MASK,
+      cursor,
+      event->time
+    );
+#else
     gdk_pointer_grab(
       priv->window,
       FALSE,
@@ -611,7 +698,7 @@ inf_text_gtk_hue_chooser_button_press_event(GtkWidget* widget,
       cursor,
       event->time
     );
-
+#endif
     gdk_cursor_unref(cursor);
     gtk_widget_grab_focus(widget);
   }
@@ -638,11 +725,17 @@ inf_text_gtk_hue_chooser_button_release_event(GtkWidget* widget,
   hue = inf_text_gtk_hue_chooser_hue_by_coords(chooser, event->x, event->y);
   inf_text_gtk_hue_chooser_set_hue(chooser, hue);
 
+#if GTK_CHECK_VERSION(2, 91, 0)
+  gdk_device_ungrab(
+    gdk_event_get_device((GdkEvent*)event),
+    event->time
+  );
+#else
   gdk_display_pointer_ungrab(
     gdk_drawable_get_display(event->window),
     event->time
   );
-
+#endif
   return TRUE;
 }
 
@@ -668,12 +761,36 @@ inf_text_gtk_hue_chooser_motion_notify_event(GtkWidget* widget,
   return TRUE;
 }
 
+#if GTK_CHECK_VERSION(2,91,0)
+static gboolean
+inf_text_gtk_hue_chooser_draw(GtkWidget* widget,
+                              cairo_t* cr)
+{
+  InfTextGtkHueChooser* chooser;
+  InfTextGtkHueChooserPrivate* priv;
+
+  chooser = INF_TEXT_GTK_HUE_CHOOSER(widget);
+  priv = INF_TEXT_GTK_HUE_CHOOSER_PRIVATE(chooser);
+
+  inf_text_gtk_hue_chooser_paint(
+    chooser,
+    cr,
+    0,
+    0,
+    gtk_widget_get_allocated_width(widget),
+    gtk_widget_get_allocated_height(widget)
+  );
+
+  return FALSE;
+}
+#else
 static gboolean
 inf_text_gtk_hue_chooser_expose_event(GtkWidget* widget,
                                       GdkEventExpose* event)
 {
   InfTextGtkHueChooser* chooser;
   InfTextGtkHueChooserPrivate* priv;
+  GtkAllocation allocation;
   GdkRectangle rect;
   GdkRectangle dest;
   cairo_t* cr;
@@ -681,33 +798,54 @@ inf_text_gtk_hue_chooser_expose_event(GtkWidget* widget,
   chooser = INF_TEXT_GTK_HUE_CHOOSER(widget);
   priv = INF_TEXT_GTK_HUE_CHOOSER_PRIVATE(chooser);
 
-
+#if GTK_CHECK_VERSION(2,18,0)
+  if(!(gtk_widget_is_drawable(widget) &&
+       event->window == gtk_widget_get_window(widget)))
+  {
+    return FALSE;
+  }
+#else
   if(!(GTK_WIDGET_DRAWABLE(widget) && event->window == widget->window))
     return FALSE;
+#endif
 
-  rect.x = widget->allocation.x;
-  rect.y = widget->allocation.y;
-  rect.width = widget->allocation.width;
-  rect.height = widget->allocation.height;
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_get_allocation(widget, &allocation);
+#else
+  allocation = widget->allocation;
+#endif
+
+  rect.x = allocation.x;
+  rect.y = allocation.y;
+  rect.width = allocation.width;
+  rect.height = allocation.height;
 
   if(!gdk_rectangle_intersect(&event->area, &rect, &dest))
     return FALSE;
 
+#if GTK_CHECK_VERSION(2,14,0)
+  cr = gdk_cairo_create(gtk_widget_get_window(widget));
+#else
   cr = gdk_cairo_create(widget->window);
-  cairo_translate(cr, widget->allocation.x, widget->allocation.y);
+#endif
+  cairo_translate(cr, allocation.x, allocation.y);
 
   inf_text_gtk_hue_chooser_paint(
     chooser,
     cr,
-    dest.x - widget->allocation.x,
-    dest.y - widget->allocation.y,
+    dest.x - allocation.x,
+    dest.y - allocation.y,
     dest.width,
     dest.height
   );
 
   cairo_destroy(cr);
 
-  if(GTK_WIDGET_HAS_FOCUS(chooser))
+#if GTK_CHECK_VERSION(2,18,0)
+  if(gtk_widget_has_focus(widget))
+#else
+  if(GTK_WIDGET_HAS_FOCUS(widget))
+#endif
   {
     /* This looks irritating: */
 #if 0
@@ -728,6 +866,7 @@ inf_text_gtk_hue_chooser_expose_event(GtkWidget* widget,
 
   return FALSE;
 }
+#endif
 
 static gboolean
 inf_text_gtk_hue_chooser_focus(GtkWidget* widget,
@@ -739,7 +878,11 @@ inf_text_gtk_hue_chooser_focus(GtkWidget* widget,
   chooser = INF_TEXT_GTK_HUE_CHOOSER(widget);
   priv = INF_TEXT_GTK_HUE_CHOOSER_PRIVATE(chooser);
 
+#if GTK_CHECK_VERSION(2,18,0)
+  if(!gtk_widget_has_focus(widget))
+#else
   if(!GTK_WIDGET_HAS_FOCUS(widget))
+#endif
   {
     gtk_widget_grab_focus(GTK_WIDGET(widget));
     return TRUE;
@@ -841,7 +984,14 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
   widget_class->unmap = inf_text_gtk_hue_chooser_unmap;
   widget_class->realize = inf_text_gtk_hue_chooser_realize;
   widget_class->unrealize = inf_text_gtk_hue_chooser_unrealize;
+#if GTK_CHECK_VERSION(2,91,6)
+  widget_class->get_preferred_height =
+    inf_text_gtk_hue_chooser_get_preferred_height;
+  widget_class->get_preferred_width =
+    inf_text_gtk_hue_chooser_get_preferred_width;
+#else
   widget_class->size_request = inf_text_gtk_hue_chooser_size_request;
+#endif
   widget_class->size_allocate = inf_text_gtk_hue_chooser_size_allocate;
   widget_class->button_press_event =
     inf_text_gtk_hue_chooser_button_press_event;
@@ -849,7 +999,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
     inf_text_gtk_hue_chooser_button_release_event;
   widget_class->motion_notify_event =
     inf_text_gtk_hue_chooser_motion_notify_event;
+#if GTK_CHECK_VERSION(2,91,0)
+  widget_class->draw = inf_text_gtk_hue_chooser_draw;
+#else
   widget_class->expose_event = inf_text_gtk_hue_chooser_expose_event;
+#endif
   widget_class->focus = inf_text_gtk_hue_chooser_focus;
   widget_class->grab_broken_event = inf_text_gtk_hue_chooser_grab_broken_event;
 
@@ -898,7 +1052,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
 
   gtk_binding_entry_add_signal(
     binding_set,
+#if GTK_CHECK_VERSION(2,90,7)
+    GDK_KEY_Up,
+#else
     GDK_Up,
+#endif
     0,
     "move",
     1,
@@ -908,7 +1066,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
 
   gtk_binding_entry_add_signal(
     binding_set,
+#if GTK_CHECK_VERSION(2,90,7)
+    GDK_KEY_KP_Up,
+#else
     GDK_KP_Up,
+#endif
     0,
     "move",
     1,
@@ -918,7 +1080,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
 
   gtk_binding_entry_add_signal(
     binding_set,
+#if GTK_CHECK_VERSION(2,90,7)
+    GDK_KEY_Down,
+#else
     GDK_Down,
+#endif
     0,
     "move",
     1,
@@ -928,7 +1094,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
 
   gtk_binding_entry_add_signal(
     binding_set,
+#if GTK_CHECK_VERSION(2,90,7)
+    GDK_KEY_KP_Down,
+#else
     GDK_KP_Down,
+#endif
     0,
     "move",
     1,
@@ -938,7 +1108,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
 
   gtk_binding_entry_add_signal(
     binding_set,
+#if GTK_CHECK_VERSION(2,90,7)
+    GDK_KEY_Right,
+#else
     GDK_Right,
+#endif
     0,
     "move",
     1,
@@ -948,7 +1122,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
 
   gtk_binding_entry_add_signal(
     binding_set,
+#if GTK_CHECK_VERSION(2,90,7)
+    GDK_KEY_KP_Right,
+#else
     GDK_KP_Right,
+#endif
     0,
     "move",
     1,
@@ -958,7 +1136,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
 
   gtk_binding_entry_add_signal(
     binding_set,
+#if GTK_CHECK_VERSION(2,90,7)
+    GDK_KEY_Left,
+#else
     GDK_Left,
+#endif
     0,
     "move",
     1,
@@ -968,7 +1150,11 @@ inf_text_gtk_hue_chooser_class_init(gpointer g_class,
 
   gtk_binding_entry_add_signal(
     binding_set,
+#if GTK_CHECK_VERSION(2,90,7)
+    GDK_KEY_KP_Left,
+#else
     GDK_KP_Left,
+#endif
     0,
     "move",
     1,
